Welcome to jaraco.compat documentation!
========================================

.. toctree::
   :maxdepth: 1

   history


.. automodule:: py23compat
    :members:
    :undoc-members:
    :show-inheritance:

.. automodule:: py24compat
    :members:
    :undoc-members:
    :show-inheritance:

.. automodule:: py25compat
    :members:
    :undoc-members:
    :show-inheritance:

.. automodule:: py26compat
    :members:
    :undoc-members:
    :show-inheritance:

.. automodule:: py27compat
    :members:
    :undoc-members:
    :show-inheritance:

.. automodule:: py31compat
    :members:
    :undoc-members:
    :show-inheritance:

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

